==> orchestra-api-4.4.2-sources.jar: org/ow2/orchestra/facade/def/impl/UntilDefinitionImpl.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.def.impl;

import org.ow2.orchestra.facade.def.UntilDefinition;

public class UntilDefinitionImpl implements UntilDefinition {

  private String expressionLanguage;
  private String deadlineExpression;

  public UntilDefinitionImpl(final UntilDefinition untilDefinition) {
    this.expressionLanguage = untilDefinition.getExpressionLanguage();
    this.deadlineExpression = untilDefinition.getDeadlineExpression();
  }

  public UntilDefinitionImpl() {
  }

  public UntilDefinitionImpl(final String expressionLanguage, final String deadlineExpression) {
    this.expressionLanguage = expressionLanguage;
    this.deadlineExpression = deadlineExpression;
  }

  public UntilDefinition copy() {
    return new UntilDefinitionImpl(this);
  }

  public String getDeadlineExpression() {
    return deadlineExpression;
  }

  public String getExpressionLanguage() {
    return expressionLanguage;
  }

}

==> orchestra-api-4.6.1-sources.jar: org/ow2/orchestra/facade/def/impl/UntilDefinitionImpl.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.def.impl;

import org.ow2.orchestra.facade.def.UntilDefinition;

public class UntilDefinitionImpl implements UntilDefinition {

  private static final long serialVersionUID = 3626453594102621021L;

  private String expressionLanguage;
  private String deadlineExpression;

  public UntilDefinitionImpl(final UntilDefinition untilDefinition) {
    this.expressionLanguage = untilDefinition.getExpressionLanguage();
    this.deadlineExpression = untilDefinition.getDeadlineExpression();
  }

  public UntilDefinitionImpl() {
  }

  public UntilDefinitionImpl(final String expressionLanguage, final String deadlineExpression) {
    this.expressionLanguage = expressionLanguage;
    this.deadlineExpression = deadlineExpression;
  }

  public UntilDefinition copy() {
    return new UntilDefinitionImpl(this);
  }

  public String getDeadlineExpression() {
    return this.deadlineExpression;
  }

  public String getExpressionLanguage() {
    return this.expressionLanguage;
  }

}
